@@ -1,11 +1,11 @@
 ;;; sensei.el --- A client for sensei  -*- lexical-binding: t; -*-
 
-;; Copyright (c) Arnaud Bailly - 2022
+;; Copyright (c) Arnaud Bailly - 2022-2026
 ;; Author: Arnaud Bailly <arnaud@pankzsoft.com>
 ;; Package-Requires: ((emacs "27.1") (projectile "2.5.0") (request "0.3.2"))
 ;; Keywords: hypermedia
-;; Package-Version: 20250831.1341
-;; Package-Revision: 3129584a6b4b
+;; Package-Version: 20260125.933
+;; Package-Revision: 4257ca13aaab
 ;; Homepage: https://abailly.github.io/sensei
 
 ;; Redistribution and use in source and binary forms, with or without
@@ -71,9 +71,6 @@
 This variable is updated every time one starts recording a note,
 according to what 'projectile-project-root' says for the current
 directory.
-
-TODO: Remove this global variable and find a way to pass the
-project directory when starting note edition.
 ")
 
 (defun sensei-send-event-note (directory on-success)
@@ -169,6 +166,10 @@ DIRECTORY is the project to record note for."
     (setq sensei-cur-directory directory)
     (switch-to-buffer buffer-name)
     (use-local-map nil)
+    ;; activate markdown mode in buffer if available
+    ;; note there's no minor markdown mode, so we rebind C-c C-c after activation
+    (when (fboundp 'markdown-mode)
+      (markdown-mode))
     (local-set-key
      (kbd "C-c C-c")
      #'sensei-send-note-and-close)))
